@@ -34,14 +34,14 @@ async def main() -> None:
     """
     # pylint: disable-msg=too-many-locals
     # pylint: disable-msg=too-many-statements
-    parser = argparse.ArgumentParser(description="Delete old toots.")
+    parser = argparse.ArgumentParser(description="Post toots from reddit posts.")
     parser.add_argument(
         "-c",
         "--config-dir",
         action="store",
         default=".",
         dest="config_dir",
-        help="Name of directory containing configurtation files to use",
+        help="Name of directory containing configuration files to use",
     )
     parser.add_argument(
         "-l",
