@@ -23,20 +23,21 @@ import aiohttp
 import asyncpraw.exceptions
 import asyncprawcore
 import magic
+import yt_dlp.utils
 from asyncpraw.models import Submission
-from bs4 import BeautifulSoup
 from imgurpython import ImgurClient
 from imgurpython.helpers.error import ImgurClientError
 from tqdm import tqdm
 from tqdm.asyncio import tqdm as aiotqdm
 
+from . import __display_name__
 from . import PROGRESS_BAR_FORMAT
 from . import USER_AGENT
 from .control import Configuration
 from .control import Secret
 from .control import SubredditConfig
 
-logger = logging.getLogger("Tootbot")
+logger = logging.getLogger(__display_name__)
 
 FATAL_TOOTBOT_ERROR = "Tootbot cannot continue, now shutting down"
 
@@ -341,14 +342,21 @@ class RedditHelper:
             promo_message (str): Any promo message that must be added to end of caption.
             Set to None if no promo message to be added
         """
-        caption = ""
+        logger.debug(
+            "RedditHelper.get_caption("
+            "submission='%s', max_len=%s, add_hash_tags='%s', promo_message='%s')",
+            submission.id,
+            max_len,
+            add_hash_tags,
+            promo_message,
+        )
         # Create string of hashtags
         hashtag_string = ""
         promo_string = ""
         hashtags_for_post = self.config.bot.hash_tags
 
         # Workout hashtags for post
-        if add_hash_tags is not None:
+        if add_hash_tags:
             hashtags_for_subreddit = [x.strip() for x in add_hash_tags.split(",")]
             hashtags_for_post = hashtags_for_subreddit + self.config.bot.hash_tags
         if hashtags_for_post:
@@ -363,12 +371,19 @@ class RedditHelper:
             len(submission.shortlink) - len(hashtag_string) - len(promo_string)
         )
 
+        caption: str = ""
         # Create contents of the Mastodon post
         if len(submission.title) < caption_max_length:
-            caption = submission.title + " "
+            temp_caption = submission.title + " "
         else:
-            caption = submission.title[caption_max_length - 2] + "... "
-        caption += hashtag_string + submission.shortlink + promo_string
+            temp_caption = submission.title[caption_max_length - 2] + "... "
+        if self.config.mastodon_config.use_caption:
+            caption += temp_caption
+        if self.config.mastodon_config.use_tags:
+            caption += hashtag_string
+        if self.config.mastodon_config.use_backlink:
+            caption += submission.shortlink
+        caption += promo_string
         return caption
 
 
@@ -509,7 +524,7 @@ class LinkedMediaHelper:
 
         return True
 
-    async def get_gfycat_image(self: LMH, img_url: str) -> Optional[str]:
+    def get_gfycat_image(self: LMH, img_url: str) -> Optional[str]:
         """get_gfycat_image downloads full resolution images from gfycat.
 
         Arguments:
@@ -520,59 +535,11 @@ class LinkedMediaHelper:
             downloaded
         """
         logger.debug("LinkedMediaHelper.get_gfycat_image(img_url=%s)", img_url)
-        gfycat_url = ""
-        file_path = self.save_dir + "/"
-        try:
-            gfycat_name = os.path.basename(urlsplit(img_url).path)
-            logger.debug(
-                "LinkedMediaHelper.get_gfycat_image(...) - gfycat_name=%s", gfycat_name
-            )
-            async with aiohttp.ClientSession(raise_for_status=True) as session:
-                async with session.get(url=img_url) as response:
-                    logger.debug(
-                        "LinkedMediaHelper.get_gfycat_image(...) - response.status=%s",
-                        response.status,
-                    )
-                    soup = BeautifulSoup(await response.text(), "html5lib")
-                    logger.debug(
-                        "LinkedMediaHelper.get_gfycat_image(...) - 'cooked soup'"
-                    )
 
-            tags = soup.find_all("source", src=True)
-            logger.debug("LinkedMediaHelper.get_gfycat_image(...) - tags=%s", tags)
-
-            for tag in tags:
-                logger.debug("LinkedMediaHelper.get_gfycat_image(...) - tag=%s", tag)
-                src = tag["src"]
-                if "thumbs" in src:
-                    continue
-                if "mp4" in src:
-                    gfycat_url = src
-
-            logger.debug(
-                "LinkedMediaHelper.get_gfycat_image(...) - gfycat_url=%s", gfycat_url
-            )
-            file_path += gfycat_name + ".mp4"
-            logger.debug(
-                "LinkedMediaHelper.get_gfycat_image(...) - file_path=%s", file_path
-            )
-        except (
-            aiohttp.ClientError,
-            TypeError,
-        ) as gfycat_error:
-            logger.error("Error downloading Gfycat link: %s", gfycat_error)
-            return None
-
-        if gfycat_url == "":
-            logger.debug("Empty Gfycat URL; no attachment to download")
-            return None
-
-        saved_paths = await get_file(
-            img_url=gfycat_url,
-            file_path=file_path,
-            progress_label="Downloading Gfycat image/video",
+        saved_paths = LinkedMediaHelper._get_video_with_yt_dlp(
+            video_url=img_url,
+            save_as=self.save_dir + "/" + os.path.basename(urlsplit(img_url).path),
         )
-
         return saved_paths
 
     async def get_reddit_image(self: LMH, img_url: str) -> Optional[str]:
@@ -653,7 +620,7 @@ class LinkedMediaHelper:
 
         return file_paths
 
-    async def get_reddit_video(self: LMH, reddit_post: Submission) -> Optional[str]:
+    def get_reddit_video(self: LMH, reddit_post: Submission) -> Optional[str]:
         """get_reddit_video downloads full resolution video from i.reddit or
         reddituploads.
 
@@ -664,17 +631,80 @@ class LinkedMediaHelper:
             file_path (string): path to downloaded video or None if no image was
             downloaded
         """
-        # Get URL for MP4 version of reddit video
-        video_url = reddit_post.media["reddit_video"]["fallback_url"]
-        file_path: str = self.save_dir + "/" + reddit_post.id + ".mp4"
-        logger.debug("Downloading Reddit video at URL %s to %s", video_url, file_path)
-
-        saved_path = await get_file(
-            img_url=video_url,
-            file_path=file_path,
-            progress_label="Downloading video from Reddit",
+        logger.debug(
+            "LinkedMediaHelper.get_reddit_video(reddit_post = %s)",
+            reddit_post.id,
         )
-        return saved_path
+        logger.debug(
+            "LinkedMediaHelper.get_reddit_video - reddit_post.media: \n%s)",
+            reddit_post.media,
+        )
+
+        # Download video with yt-dlp
+        yt_dlp_url = reddit_post.media["reddit_video"]["hls_url"]
+        print(f"Downloading Reddit video from {yt_dlp_url}")
+
+        filepath = LinkedMediaHelper._get_video_with_yt_dlp(
+            video_url=yt_dlp_url,
+            save_as=self.save_dir + "/" + reddit_post.id,
+        )
+        return filepath
+
+    @staticmethod
+    def _get_video_with_yt_dlp(video_url: str, save_as: str) -> Optional[str]:
+        """Downloads video files with embedded yt-dlp.
+
+        Arguments:
+            video_url (string): URL for video to download
+            save_as (string): path and file name excluding file extension for yt-dlp to
+                download video file to
+
+        Returns:
+            (string) containing file name inclusive file extension and path where yt-dlp
+                has saved the downloaded video.
+                This can be None if yt-dlp has been unsuccessful.
+        """
+        logger.debug(
+            "LinkedMediaHelper._get_video_with_yt_dlp(video_url=%s, save_as=%s)",
+            video_url,
+            save_as,
+        )
+        yt_dlp_options = {
+            "outtmpl": save_as + ".%(ext)s",
+            "quiet": "true",
+            "ignoreerrors": "true",
+            "progress": "true",
+            "format": "bestvideo+bestaudio",
+        }
+
+        with yt_dlp.YoutubeDL(yt_dlp_options) as ytdl:
+            meta = ytdl.extract_info(video_url, download=True)
+            meta_san = ytdl.sanitize_info(meta)
+
+        # If there was an error with yt-dlp download meta will be None
+        if not meta:
+            logger.debug(
+                "LinkedMediaHelper.get_reddit_video - yt-dlp unsuccessful -> None"
+            )
+            return None
+
+        yt_dlp_filepath: str = meta.get("filepath")
+        if yt_dlp_filepath:
+            logger.debug(
+                "LinkedMediaHelper.get_reddit_video - yt-dlp DIRECT filepath: '%s'",
+                yt_dlp_filepath,
+            )
+        else:
+            yt_dlp_filepath = meta_san.get("requested_downloads")[0].get("filepath")
+            logger.debug(
+                "LinkedMediaHelper.get_reddit_video - yt-dlp 3 DEEP filepath: '%s'",
+                yt_dlp_filepath,
+            )
+        logger.debug(
+            "LinkedMediaHelper.get_reddit_video (...) -> '%s'", yt_dlp_filepath
+        )
+
+        return yt_dlp_filepath
 
     async def get_giphy_image(self: LMH, img_url: str) -> Optional[str]:
         """get_giphy_image downloads full or low resolution image from giphy.
@@ -850,9 +880,7 @@ class MediaAttachment:
                 "Reddit API returned no media for this URL: %s", self.media_url
             )
         elif "v.redd.it" in self.media_url:
-            saved_media_path = await self.image_helper.get_reddit_video(
-                self.reddit_post
-            )
+            saved_media_path = self.image_helper.get_reddit_video(self.reddit_post)
             file_paths.append(saved_media_path)
 
         elif "imgur.com" in self.media_url:
@@ -860,7 +888,7 @@ class MediaAttachment:
             file_paths.extend(saved_media_paths)
 
         elif "gfycat.com" in self.media_url:
-            saved_media_path = await self.image_helper.get_gfycat_image(self.media_url)
+            saved_media_path = self.image_helper.get_gfycat_image(self.media_url)
             file_paths.append(saved_media_path)
 
         elif "giphy.com" in self.media_url:
