@@ -92,7 +92,7 @@ class PostRecorder:
             "SELECT * FROM post where id=:id", {"id": identifier}
         )
         if await cursor.fetchone():
-            logger.debug("PostRecorder.duplicate_check(...) - returns True")
+            logger.debug("PostRecorder.duplicate_check(...) -> True")
             return True
 
         # check for Shared URL
@@ -100,7 +100,7 @@ class PostRecorder:
             "SELECT * FROM share where url=:url", {"url": identifier}
         )
         if await cursor.fetchone():
-            logger.debug("PostRecorder.duplicate_check(...) - returns True")
+            logger.debug("PostRecorder.duplicate_check(...) -> True")
             return True
 
         # check for attachment hash
@@ -108,10 +108,10 @@ class PostRecorder:
             "SELECT * FROM hash where checksum=:checksum", {"checksum": identifier}
         )
         if await cursor.fetchone():
-            logger.debug("PostRecorder.duplicate_check(...) - returns True")
+            logger.debug("PostRecorder.duplicate_check(...) -> True")
             return True
 
-        logger.debug("PostRecorder.duplicate_check(...) - returns False")
+        logger.debug("PostRecorder.duplicate_check(...) -> False")
         return False
 
     async def log_post(
@@ -274,12 +274,17 @@ class MastodonConfig:
     an error to allow throttling of posting toots in a controlled manner
     """
 
+    # pylint: disable=too-many-instance-attributes
+
     domain: str
     media_always_sensitive: bool
     post_visibility: str
     throttling_enabled: bool
     throttling_max_delay: int
     number_of_errors: int
+    use_caption: bool
+    use_tags: bool
+    use_backlink: bool
 
 
 @dataclass
@@ -362,6 +367,9 @@ class Configuration:
             throttling_enabled=str_to_bool(config["Mastodon"]["ThrottlingEnabled"]),
             throttling_max_delay=int(config["Mastodon"]["ThrottlingMaxDelay"]),
             number_of_errors=0,
+            use_caption=config["Mastodon"].getboolean("UseCaption", fallback=True),
+            use_tags=config["Mastodon"].getboolean("UseTags", fallback=True),
+            use_backlink=config["Mastodon"].getboolean("UseBacklink", fallback=True),
         )
         subreddits = await Configuration._load_subreddits_settings(config)
 
@@ -383,7 +391,7 @@ class Configuration:
     ) -> List[SubredditConfig]:
         subreddits = []
         for subreddit, hashtags in config.items("Subreddits"):
-            subreddits.append(SubredditConfig(subreddit, hashtags))
+            subreddits.append(SubredditConfig(subreddit, hashtags.strip()))
         return subreddits
 
     @staticmethod
