@@ -99,6 +99,14 @@ PostVisibility : unlisted
 ThrottlingEnabled : true
 # Maximum delay in seconds between attempts to post a toot when throttling.
 ThrottlingMaxDelay : 86400
+# Should tootbot add a caption to the toot? This defaults to true and will use the title
+# of the reddit post as source for the caption
+UseCaption : true
+# Include hash tags in toots posted? This setting defaults to true and will use the
+# hash tags defined in this config file.
+UseTags : true
+# Include a link back to the reddit post being tooted. This defaults to true
+UseBacklink : true
 """
 
 
