@@ -20,6 +20,7 @@ from minimal_activitypub.client_2_server import ActivityPubError
 from minimal_activitypub.client_2_server import ApiError
 from tqdm.asyncio import tqdm
 
+from . import __display_name__
 from . import CLIENT_WEBSITE
 from . import USER_AGENT
 from .collect import LinkedMediaHelper
@@ -35,7 +36,7 @@ from .control import Secret
 # With two private methods it is still nice to have these in their own module
 
 
-logger = logging.getLogger("Tootbot")
+logger = logging.getLogger(__display_name__)
 
 MP = TypeVar("MP", bound="MastodonPublisher")
 FileManagerClass = TypeVar("FileManagerClass", bound="FileManager")
@@ -192,7 +193,7 @@ class MastodonPublisher:
 
                 # Find out if we have any attachments to include with toot.
                 logger.debug(
-                    "Getting attachments for post %s",
+                    "MastodonPublisher.make_post - Getting attachments for post %s",
                     source_posts[post].id,
                 )
                 attachments = MediaAttachment(source_posts[post], media_helper)
@@ -201,10 +202,14 @@ class MastodonPublisher:
 
                 # Make sure the post contains media,
                 # if MEDIA_POSTS_ONLY in config is set to True
+                logger.debug(
+                    "MastodonPublisher.make_post - attachments.media_paths: %s",
+                    attachments.media_paths,
+                )
                 if self.media_only and len(attachments.media_paths) == 0:
                     logger.warning(
-                        "Skipping %s, non-media posts disabled or "
-                        "media file not found",
+                        "MastodonPublisher.make_post - "
+                        "Skipping %s, non-media posts disabled or media file not found",
                         source_posts[post].id,
                     )
                     # Log the post anyway
@@ -230,6 +235,10 @@ class MastodonPublisher:
 
                     # Upload media files if available
                     media_ids = await self._post_attachments(attachments)
+                    if self.media_only and len(media_ids) == 0:
+                        # Skip posts where no media has been able to be uploaded
+                        # and we've set media_only posts to True
+                        continue
 
                     # Determine if spoiler is necessary
                     spoiler = None
@@ -245,6 +254,7 @@ class MastodonPublisher:
                         spoiler_text=spoiler,
                     )
                     print(f'Posted to Mastodon: "{caption}" (at {toot["url"]})')
+                    logger.debug("Posted to Mastodon: %s (at %s)", caption, toot["url"])
 
                     # Log the toot
                     await self.bot.post_recorder.log_post(
